@@ -1,28 +1,7 @@
-import json
-import os
-import threading
-import time
-
 from mqtool.kit import Kafka_consumer, Kafka_producer
-# from mqtool.kit.push_metrics import IO_metrics
 from mqtool.kit.tornado_server import Tornado_http
-# from mqtool.model.algo_load import load_dir
 from mqtool.utils import *
 
-# algo_list = load_dir('./algorithm')
-# if len(algo_list) == 0:
-#     logger.info('未加载到算法模型，程序退出！')
-#     exit()
-# algo = algo_list[0]
-## 统计算子IO指标
-# input = 0
-# output = 0
-# input_befor = 0
-# output_befor = 0
-# time_differ_list = []
-# data_type = ''
-# algo = ''
-
 
 def start():
     return {"status": "algorithm service success"}
@@ -49,40 +28,8 @@ def api(data):
     return algo(data)
 
 
-# def cron_push():
-#     """
-#     定时push metrics
-#     :return:
-#     """
-#     global input, output, input_befor, output_befor,time_differ_list
-#     push_addr = os.getenv("PUSHTOGATEWAY", None)
-#     if push_addr is None:
-#         logger.info("None pushgateway address")
-#     if push_addr is not None:
-#         info = "pushgateway address:" + push_addr
-#         logger.info(info)
-#         while True:
-#             time.sleep(60)
-#             IO_metrics(push_addr,input,output,input_befor,output_befor,time_differ_list)
-#             input_befor,output_befor= input,output
-#             time_differ_list = []
-
-
-
-# def push_task():
-#     """
-#     开启新线程推送指标
-#     :return:
-#     """
-#     try:
-#         th = threading.Thread(target=cron_push)
-#         th.start()
-#     except:
-#         logger.exception("push metrics error")
-
 def aistart(run):
     try:
-        # push_task()
         global algo
         global data_type
         algo = run
@@ -100,25 +47,19 @@ def aistart(run):
                                           is_json=True)
             for message in data:
                 try:
-                    # input += 1
                     logger.info('receive data')
                     mes = json.loads(message.decode())
-                    # time_befor=time.time()
                     res = api(mes)
-                    # time_after = time.time()
-                    # time_differ_list.append(time_after-time_befor)
                     if res is not None:
                         if isinstance(res, list):
                             for item in res:
                                 if sinktopic is not None:
                                     producer.send_df(item)
                                 http_post(storage_url, item)
-                                # output +=1
                         else:
                             if sinktopic is not None:
                                 producer.send_df(res)
                             http_post(storage_url, res)
-                            # output += 1
                 except:
                     logger.exception("deal data error")
 
